diff src/cmdexpand.c @ 24256:b471a413d36a v8.2.2669

patch 8.2.2669: command line completion does not work after "vim9" Commit: https://github.com/vim/vim/commit/df749a2b9cab579b8c0ca6ca91889aa03d2da704 Author: Bram Moolenaar <Bram@vim.org> Date: Sun Mar 28 15:29:43 2021 +0200 patch 8.2.2669: command line completion does not work after "vim9" Problem: Command line completion does not work after "vim9". Solution: Include the "9". (Naohiro Ono, closes https://github.com/vim/vim/issues/8025)
author Bram Moolenaar <Bram@vim.org>
date Sun, 28 Mar 2021 15:30:05 +0200
parents 32a9d01c2a49
children 7334bf933510
line wrap: on
line diff
--- a/src/cmdexpand.c
+++ b/src/cmdexpand.c
@@ -1020,8 +1020,9 @@ set_one_cmd_context(
 	p = cmd;
 	while (ASCII_ISALPHA(*p) || *p == '*')    // Allow * wild card
 	    ++p;
-	// a user command may contain digits
-	if (ASCII_ISUPPER(cmd[0]))
+	// A user command may contain digits.
+	// Include "9" for "vim9*" commands; "vim9cmd" and "vim9script".
+	if (ASCII_ISUPPER(cmd[0]) || STRNCMP("vim9", cmd, 4) == 0)
 	    while (ASCII_ISALNUM(*p) || *p == '*')
 		++p;
 	// for python 3.x: ":py3*" commands completion